@@ -26,6 +26,9 @@
 
 #include <memory>
 
+#include <KLocalizedString>
+
+
 class Session {
 public:
     QString file;
@@ -43,8 +46,17 @@ public:
 };
 
 SessionModel::SessionModel(QObject *parent) : QAbstractListModel(parent), d(new SessionModelPrivate()) {
-    // read session files
-    QDir dir("/usr/share/xsessions");
+    loadDir("/usr/share/xsessions", SessionTypeX);
+    loadDir("/usr/share/wayland-sessions", SessionTypeWayland);
+}
+
+SessionModel::~SessionModel() {
+    delete d;
+}
+
+void SessionModel::loadDir(const QString &path, SessionType type)
+{
+    QDir dir(path);
     dir.setNameFilters(QStringList() << "*.desktop");
     dir.setFilter(QDir::Files);
     // read session
@@ -53,45 +65,28 @@ SessionModel::SessionModel(QObject *parent) : QAbstractListModel(parent), d(new
         if (!inputFile.open(QIODevice::ReadOnly))
             continue;
         SessionPtr si { new Session { session, "", "", "" } };
-        bool isHidden = false;
-        QString current_section;
         QTextStream in(&inputFile);
         while (!in.atEnd()) {
             QString line = in.readLine();
-
-            if (line.startsWith(QLatin1String("["))) {
-                // The section name ends before the last ] before the start of a comment
-                int end = line.lastIndexOf(QLatin1Char(']'), line.indexOf(QLatin1Char('#')));
-                if (end != -1)
-                    current_section = line.mid(1, end - 1);
-            }
-
-            if (current_section != QLatin1String("Desktop Entry"))
-                continue; // We are only interested in the "Desktop Entry" section
-
-            if (line.startsWith("Name="))
+            if (line.startsWith("Name=")) {
                 si->name = line.mid(5);
+                if (type == SessionTypeWayland) {
+                    //we want to exactly match the SDDM prompt which is formatted in this way
+                    si->name = i18nc("%1 is the name of a session", "%1 (Wayland)", si->name);
+                }
+            }
             if (line.startsWith("Exec="))
                 si->exec = line.mid(5);
             if (line.startsWith("Comment="))
                 si->comment = line.mid(8);
-            if (line.startsWith(QLatin1String("Hidden=")))
-                isHidden = line.mid(7).toLower() == QLatin1String("true");
         }
-        if (!isHidden) {
-            // add to sessions list
-            d->sessions.push_back(si);
-        }
-
+        // add to sessions list
+        d->sessions.push_back(si);
         // close file
         inputFile.close();
     }
 }
 
-SessionModel::~SessionModel() {
-    delete d;
-}
-
 QHash<int, QByteArray> SessionModel::roleNames() const {
     // set role names
     QHash<int, QByteArray> roleNames;
